@@ -1,6 +1,6 @@
 package Fey::DBIManager::Source;
 BEGIN {
-  $Fey::DBIManager::Source::VERSION = '0.12';
+  $Fey::DBIManager::Source::VERSION = '0.13';
 }
 
 use strict;
@@ -130,6 +130,20 @@ sub BUILD {
     return $self;
 }
 
+sub clone {
+    my $self = shift;
+
+    my %p = map { $_ => $self->$_() }
+        grep { defined $self->$_() }
+        qw( dsn username password attributes post_connect auto_refresh );
+
+    return ( ref $self )->new(
+        name => 'Clone of ' . $self->name(),
+        %p,
+        @_,
+    );
+}
+
 sub _required_dbh_attributes {
     return (
         AutoCommit         => 1,
@@ -283,7 +297,7 @@ Fey::DBIManager::Source - Wraps a single DBI handle
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -398,6 +412,15 @@ source connects supports nested transactions. It does this by trying
 to issue two calls to C<< $dbh->begin_work() >> followed by two calls
 to C<< $dbh->rollback() >> (in an eval block).
 
+=head2 $source->clone(...)
+
+Returns a new source which is a clone of the original. If no name is provided,
+it is created as "Clone of <original name>". The cloned source I<does not>
+share the original's database handle.
+
+Any arguments passed to this method are passed to the constructor when
+creating the clone.
+
 =head1 REQUIRED ATTRIBUTES
 
 In order to provide consistency for C<Fey::ORM>, sources enforce a set
